@@ -46,6 +46,9 @@ roundR <- function(roundin, level = 2, smooth = FALSE,
       ) + 1
     )
   )
+  if(is.infinite(roundlevel)) {
+    roundlevel <- level
+  }
   roundout[which(!is.na(roundout))] <-
     round(roundin[which(!is.na(roundin))], roundlevel)
   if (smooth & max(abs(roundout), na.rm = TRUE) != 0) {
@@ -89,7 +92,7 @@ markSign <- function(SignIn, plabel = c("n.s.", "+", "*", "**", "***")) {
   return(SignOut)
 }
 
-#' Re-format p-values, avoiding rounding to 0
+#' Re-format p-values, avoiding rounding to 0 and adding surprisal if requested
 #'
 #' \code{formatP} simplifies p-values by rounding to the maximum of p or a
 #' predefined level. Optionally < or = can be added, as well as
@@ -101,17 +104,21 @@ markSign <- function(SignIn, plabel = c("n.s.", "+", "*", "**", "***")) {
 #' @param pretext Should = or < be added before p (default=FALSE)?
 #' @param mark Should significance level be added after p (default=FALSE)?
 #' @param german_num change dot (default) to comma?
+#' @param add.surprisal Add surprisal aka Shannon information to p-value (default=FALSE)?
+#' @param sprecision Rounding level for surprisal (default=1).
 #'
 #' @returns vector or matrix (depending on type of pIn) with type character (default) or numeric,
 #' depending on parameter textout
 #'
 #' @examples
 #' formatP(0.012345)
+#' formatP(0.012345, add.surprisal = TRUE)
 #' formatP(0.012345, ndigits = 4)
 #' formatP(0.000122345, ndigits = 3, pretext = TRUE)
 #' @export
 formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE, 
-                    mark = FALSE, german_num = FALSE) {
+                    mark = FALSE, german_num = FALSE,
+                    add.surprisal = FALSE, sprecision = 1) {
   decimal.mark <- ifelse(german_num, ",", ".")
   pIn_is_matrix <- is.matrix(pIn)
  if(pIn_is_matrix){
@@ -119,7 +126,7 @@ formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE,
  } else{
    pIn <- as.numeric(pIn)
  }
-    formatp <- NA_character_
+  formatp <- NA_character_
   if (length(na.omit(pIn))>0) {
     if (!pIn_is_matrix) {
       pIn <- matrix(pIn)
@@ -156,7 +163,14 @@ formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE,
         ncol = ncol(pIn)
       )
     }
-    if (textout == FALSE & pretext == FALSE) {
+    if(add.surprisal){
+      s <- apply(pIn,MARGIN = c(1,2),surprisal, precision = sprecision)
+      if(german_num){
+        s <- str_replace(s,'\\.',',')
+      }
+      formatp <- paste0(formatp,', s = ',s)
+    }
+    if (textout == FALSE & pretext == FALSE & add.surprisal == FALSE) {
       formatp <- apply(formatp, MARGIN = c(1, 2), as.numeric)
     }
     if(!pIn_is_matrix){
@@ -171,8 +185,8 @@ formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE,
 #'
 #' \code{FindVars} looks up colnames (by default for data-frame rawdata)
 #' based on parts of names, using regular expressions. Be warned that
-#' special characters as e.g. `[` `(` need to be escaped or replaced by .
-#' Exlusion rules may be specified as well.
+#' special characters as e.g. `[` `(` need to be escaped or replaced by `.`
+#' Exclusion rules may be specified as well.
 #'
 #' @param varnames Vector of pattern to look for.
 #' @param allnames Vector of values to detect pattern in; by default, colnames(rawdata).
@@ -180,6 +194,8 @@ formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE,
 #' @param exclude Vector of pattern to exclude from found names.
 #' @param casesensitive Logical if case is respected in matching (default FALSE: a<>A)
 #' @param fixed Logical, match as is, argument is passed to [grep()]. 
+#' @param return_symbols Should names be reported as symbols additionally? (Default FALSE)
+#' 
 #' @export
 #' @return A list with index, names, backticked names, and symbols
 #' @examples
@@ -187,12 +203,12 @@ formatP <- function(pIn, ndigits = 3, textout = TRUE, pretext = FALSE,
 #' FindVars(varnames = c("^c", "g"), allnames = colnames(mtcars), exclude = "r")
 #' rawdata <- mtcars
 #' FindVars(varnames = c("^c", "g"))
-FindVars <- function(varnames, allnames = NULL,
+FindVars <- function(varnames, allnames = colnames(rawdata),
                      exact = FALSE, exclude = NA, casesensitive = TRUE,
-                     fixed = FALSE) {
-  if (is.null(allnames)) {
-    allnames <- colnames(get("rawdata"))
-  }
+                     fixed = FALSE, return_symbols=FALSE) {
+  # if (is.null(allnames)) {
+  #   allnames <- colnames(get("rawdata"))
+  # }
   if (fixed) {
     exact <- FALSE
   }
@@ -230,17 +246,29 @@ FindVars <- function(varnames, allnames = NULL,
     }
     vars <- unique(vars)
   }
-  return(list(
+  if(return_symbols) {
+    return_list <- list(
     index = vars,
     names = allnames[vars],
     bticked = bt(allnames[vars]),
     symbols = rlang::syms(allnames[vars]),
-    count = length(vars)
-  ))
+    count = length(vars))
+  } else {
+    return_list <- list(
+      index = vars,
+      names = allnames[vars],
+      bticked = bt(allnames[vars]),
+      count = length(vars))
+  }
+  return(return_list)
 }
 
 #' Enhanced kable with definable number of rows/columns for splitting
 #'
+#' `r lifecycle::badge('superseded')`
+#' 
+#' package flextable is a more powerful alternative
+#' 
 #' \code{print_kable} formats and prints tibbles/df's in markdown with splitting
 #' into sub-tables with repeated caption and header.
 #'
@@ -250,10 +278,16 @@ FindVars <- function(varnames, allnames = NULL,
 #' @param caption header.
 #' @param ... Further arguments passed to [kable].
 #' @return No return value, called for side effects.
+#' @examples 
+#' \dontrun{
+#' print_kable(mtcars, caption = "test")
+#' }
 #' @export
 print_kable <- function(t, nrows = 30, caption = "",
                         ncols = 100, ...) {
-  # require(knitr)
+  lifecycle::deprecate_warn(when = '0.8.0',
+                            what = 'print_kable()',
+                            with = 'flextable::flextable()') # require(knitr)
   for (block_i in 1:ceiling(nrow(t) / nrows)) {
     for (col_i in 1:ceiling((ncol(t) - 1) / ncols)) {
       if (block_i + col_i > 2) {
@@ -400,3 +434,18 @@ tab.search <- function(searchdata = rawdata, pattern,
   }
   return(positions)
 }
+
+#' Compute surprisal aka Shannon information from p-values
+#' 
+#' \code{surprisal} takes p-values and returns s, a value representing the
+#' number of consecutive heads on a fair coin, that would be as surprising 
+#' as the p-value
+#' 
+#' @param p a vector of p-values
+#' @param precision rounding level with default 1
+#'
+#' @return a character vector of s-values
+#' @export
+surprisal <- function(p, precision = 1){
+round(-log2(as.numeric(p)),precision) %>% as.character()
+}
