@@ -63,7 +63,7 @@ meansd <- function(x, roundDig = 2, drop0 = FALSE, groupvar = NULL,
       out <- paste0(
         out, rangesep, " [",
         apply(matrix(meansd[, 3:4], ncol = 2), 1, paste,
-          collapse = " -> "
+              collapse = " -> "
         ), "]"
       ) # \u22ef
     }
@@ -122,8 +122,8 @@ median_quart <- function(x, nround = NULL, probs = c(.25, .5, .75),
       quart <- matrix(
         unlist(
           by(x, groupvar, quantile,
-            probs = c(probs, 0, 1), na.rm = TRUE,
-            type = qtype
+             probs = c(probs, 0, 1), na.rm = TRUE,
+             type = qtype
           )
         ),
         ncol = length(probs) + 2, byrow = TRUE
@@ -140,11 +140,11 @@ median_quart <- function(x, nround = NULL, probs = c(.25, .5, .75),
     if (is.null(nround)) {
       colcount <- ncol(quart)
       quart[, 1:(colcount - 3)] <- roundR(quart[, 1:(colcount - 3)],
-        level = roundDig, drop0 = drop0, .german = .german
+                                          level = roundDig, drop0 = drop0, .german = .german
       )
       quart[, (colcount - 2):(colcount - 1)] <-
         roundR(as.numeric(quart[, (colcount - 2):(colcount - 1)]),
-          level = roundDig, drop0 = drop0, .german = .german
+               level = roundDig, drop0 = drop0, .german = .german
         )
       if (prettynum) {
         #   quart <- apply(quart,1:2,function(x){
@@ -160,11 +160,11 @@ median_quart <- function(x, nround = NULL, probs = c(.25, .5, .75),
       if (prettynum) {
         quart <- apply(quart, 1:2, function(x) {
           formatC(as.numeric(x),
-            digits = nround,
-            format = "f",
-            big.mark = bigmark,
-            decimal.mark = decimal,
-            preserve.width = "common", drop0trailing = FALSE
+                  digits = nround,
+                  format = "f",
+                  big.mark = bigmark,
+                  decimal.mark = decimal,
+                  preserve.width = "common", drop0trailing = FALSE
           )
         })
       }
@@ -203,7 +203,7 @@ meanse <- function(x, mult = 1, roundDig = 2, drop0 = FALSE) {
   m <- mean(x, na.rm = TRUE)
   s <- sd(x, na.rm = TRUE) / sqrt(length(na.omit(x)))
   ms <- roundR(c(m, s * mult),
-    level = roundDig, drop0 = drop0
+               level = roundDig, drop0 = drop0
   )
   out <- paste(ms[1], ms[2], sep = "\u00B1")
   return(out)
@@ -212,17 +212,37 @@ meanse <- function(x, mult = 1, roundDig = 2, drop0 = FALSE) {
 
 #' Compute standard error of median.
 #'
-#' \code{median_cl_boot} is based on \code{\link{mad}}/square root(n)
+#' \code{medianse} is based on \code{\link{mad}}/square root(n)
 #'
 #' @param x Data for computation.
 #'
 #' @return numeric vector with SE Median.
 #'
 #' @examples
-#' # basic usage of meanse
+#' # basic usage of medianse
+#' medianse(x = mtcars$wt)
+#' @export
+medianse <- function(x) {
+  mad(x, na.rm = TRUE) / sqrt(length(na.omit(x)))
+}
+
+#' Compute standard error of median 
+#'
+#' \code{se_median} is based on \code{\link{mad}}/square root(n)
+#' (Deprecated, please see \link{medianse}, which is the same but named more consistently)
+#'
+#' @param x Data for computation.
+#'
+#' @return numeric vector with SE Median.
+#'
+#' @examples
+#' # basic usage of se_median
+#' \dontrun{
 #' se_median(x = mtcars$wt)
+#' }
 #' @export
 se_median <- function(x) {
+  .Deprecated('medianse')
   mad(x, na.rm = TRUE) / sqrt(length(na.omit(x)))
 }
 
@@ -239,7 +259,7 @@ se_median <- function(x) {
 #' @return A tibble with one row and three columns: Median, CIlow, CIhigh.
 #'
 #' @examples
-#' # basic usage of meanse
+#' # basic usage of median_cl_boot
 #' median_cl_boot(x = mtcars$wt)
 #' @export
 median_cl_boot <- function(x, conf = 0.95, type = "basic", nrepl = 10^3) {
@@ -261,7 +281,7 @@ median_cl_boot <- function(x, conf = 0.95, type = "basic", nrepl = 10^3) {
 #' \code{cat_desc_stats} computes absolute and relative frequencies for
 #' categorical data with a number of formatting options.
 #'
-#' @param quelle Data for computation.
+#' @param source Data for computation. Previously "quelle".
 #' @param separator delimiter between results per level, preset as ' '.
 #' @param return_level Should levels be reported?
 #' @param ndigit Digits for rounding of relative frequencies.
@@ -271,6 +291,7 @@ median_cl_boot <- function(x, conf = 0.95, type = "basic", nrepl = 10^3) {
 #' @param prettynum logical, apply prettyNum to results?
 #' @param .german logical, should "." and "," be used as bigmark and decimal?
 #' Sets prettynum to TRUE.
+#' @param quelle deprecated, retained for compatibility, use 'source' instead.
 #'
 #' @return
 #' Structure depends on parameter return_level:
@@ -287,33 +308,37 @@ median_cl_boot <- function(x, conf = 0.95, type = "basic", nrepl = 10^3) {
 #' cat_desc_stats(mtcars$gear, groupvar = mtcars$am)
 #' cat_desc_stats(mtcars$gear, groupvar = mtcars$am, singleline = TRUE)
 #' @export
-cat_desc_stats <- function(quelle, separator = " ",
+cat_desc_stats <- function(source=NULL, separator = " ",
                            return_level = TRUE,
                            ndigit = 0,
                            groupvar = NULL,
                            singleline = FALSE,
                            percent = TRUE,
                            prettynum = FALSE,
-                           .german = FALSE) {
+                           .german = FALSE,
+                           quelle=NULL) {
+  if(!is.null(quelle)) {
+    source <- quelle
+  }
   percent <- ifelse(percent, "%", "")
   bigmark <- ifelse(.german, ".", ",")
   decimal <- ifelse(.german, ",", ".")
-  if (!is.factor(quelle)) {
-    # if(is.numeric(quelle)) {
-    #   quelle<-factor(quelle,
-    #                  levels=sort(unique(quelle)),
-    #                  labels=sort(unique(quelle)))
+  if (!is.factor(source)) {
+    # if(is.numeric(source)) {
+    #   source<-factor(source,
+    #                  levels=sort(unique(source)),
+    #                  labels=sort(unique(source)))
     # } else {
-    quelle <- factor(quelle)
+    source <- factor(source)
   }
-  level <- levels(quelle) %>% enframe(name = NULL)
+  level <- levels(source) %>% enframe(name = NULL)
   if (singleline) {
-    level <- paste(levels(quelle), sep = "", collapse = separator)
+    level <- paste(levels(source), sep = "", collapse = separator)
   }
   if (is.null(groupvar)) {
-    tableout <- matrix(table(quelle),
-      nrow = length(levels(quelle)),
-      byrow = FALSE
+    tableout <- matrix(table(source),
+                       nrow = length(levels(source)),
+                       byrow = FALSE
     )
     colnames(tableout) <- "abs"
     pt_temp <- round(
@@ -325,18 +350,18 @@ cat_desc_stats <- function(quelle, separator = " ",
     }
     if (prettynum) {
       pt_temp <- formatC(pt_temp,
-        digits = ndigit,
-        format = "f",
-        big.mark = bigmark,
-        decimal.mark = decimal,
-        preserve.width = "common", drop0trailing = FALSE
+                         digits = ndigit,
+                         format = "f",
+                         big.mark = bigmark,
+                         decimal.mark = decimal,
+                         preserve.width = "common", drop0trailing = FALSE
       )
       tableout <- formatC(tableout,
-        digits = 0,
-        format = "f",
-        big.mark = bigmark,
-        decimal.mark = decimal,
-        preserve.width = "common"
+                          digits = 0,
+                          format = "f",
+                          big.mark = bigmark,
+                          decimal.mark = decimal,
+                          preserve.width = "common"
       )
     }
     ptableout <- matrix(paste0(
@@ -344,32 +369,32 @@ cat_desc_stats <- function(quelle, separator = " ",
       pt_temp,
       percent, ")"
     ),
-    nrow = length(levels(quelle)),
+    nrow = length(levels(source)),
     byrow = FALSE
     )
     colnames(ptableout) <- "rel"
   } else {
-    tableout <- matrix(unlist(by(quelle, groupvar, table)),
-      nrow = length(levels(quelle)),
-      byrow = FALSE
+    tableout <- matrix(unlist(by(source, groupvar, table)),
+                       nrow = length(levels(source)),
+                       byrow = FALSE
     )
     colnames(tableout) <- glue::glue("abs{levels(factor(groupvar))}")
-
+    
     pt_temp <- round(100 * prop.table(tableout, margin = 2), ndigit)
     if (prettynum) {
       pt_temp <- formatC(pt_temp,
-        digits = ndigit,
-        format = "f",
-        big.mark = bigmark,
-        decimal.mark = decimal,
-        preserve.width = "common", drop0trailing = FALSE
+                         digits = ndigit,
+                         format = "f",
+                         big.mark = bigmark,
+                         decimal.mark = decimal,
+                         preserve.width = "common", drop0trailing = FALSE
       )
       tableout <- formatC(tableout,
-        digits = 0,
-        format = "f",
-        big.mark = bigmark,
-        decimal.mark = decimal,
-        preserve.width = "common"
+                          digits = 0,
+                          format = "f",
+                          big.mark = bigmark,
+                          decimal.mark = decimal,
+                          preserve.width = "common"
       )
     }
     ptableout <- matrix(
@@ -377,36 +402,36 @@ cat_desc_stats <- function(quelle, separator = " ",
         " (", pt_temp,
         percent, ")"
       ),
-      nrow = length(levels(quelle)),
+      nrow = length(levels(source)),
       byrow = FALSE
     )
     colnames(ptableout) <- glue::glue("rel{levels(factor(groupvar))}")
   }
-  zwert <- purrr::map2(tableout, ptableout, glue::glue) %>%
+  zvalue <- purrr::map2(tableout, ptableout, glue::glue) %>%
     as.character() %>%
     matrix(
-      nrow = length(levels(quelle)),
+      nrow = length(levels(source)),
       byrow = FALSE
     ) %>%
     as_tibble(.name_repair = "minimal")
   if (is.null(groupvar)) {
-    colnames(zwert) <- "desc"
+    colnames(zvalue) <- "desc"
   } else {
-    colnames(zwert) <- glue::glue("desc{levels(factor(groupvar))}")
+    colnames(zvalue) <- glue::glue("desc{levels(factor(groupvar))}")
   }
   if (singleline) {
-    zwert <- purrr::map(zwert,
-      .f = function(x) {
-        glue::glue_collapse(x, sep = separator)
-      }
+    zvalue <- purrr::map(zvalue,
+                         .f = function(x) {
+                           glue::glue_collapse(x, sep = separator)
+                         }
     ) %>%
       as_tibble()
   }
-  levdesstats <- list(level = level, freq = zwert)
+  levdesstats <- list(level = level, freq = zvalue)
   if (return_level == TRUE) {
     return(levdesstats)
   } else {
-    return(zwert)
+    return(zvalue)
   }
 }
 
@@ -438,4 +463,4 @@ var_coeff <- function(x) {
 #' @export
 SEM <- function(x) {
   return(sd(x, na.rm = TRUE) / sqrt(length(na.omit(x))))
-}
+}
\ No newline at end of file
